package com.apkfuns.logutils;

import android.text.TextUtils;
import android.util.Log;
import com.apkfuns.logutils.file.LogFileParam;
import com.apkfuns.logutils.parser.LocalParserManager;
import com.apkfuns.logutils.utils.ObjectUtil;
import com.apkfuns.logutils.utils.Utils;
import java.io.File;
import java.io.StringReader;
import java.io.StringWriter;
import java.util.IllegalFormatConversionException;
import java.util.Iterator;
import java.util.MissingFormatArgumentException;
import java.util.UnknownFormatConversionException;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

/* loaded from: classes.dex */
class Logger implements Printer {
    private static final String[] CHARACTER_TABLE = {"➀", "➁", "➂", "➃", "➄", "➅", "➆", "➇", "➈", "➉"};
    private static final int MIN_STACK_OFFSET = 5;
    private final ThreadLocal<String> localTags = new ThreadLocal<>();
    private LogConfigImpl mLogConfig = LogConfigImpl.getInstance();
    private Log2FileConfigImpl log2FileConfig = Log2FileConfigImpl.getInstance();

    Logger() {
        this.mLogConfig.addParserClass(LocalParserManager.DEFAULT_PARSE_CLASS);
    }

    public Printer setTag(String str) {
        if (!TextUtils.isEmpty(str) && this.mLogConfig.isEnable()) {
            this.localTags.set(str);
        }
        return this;
    }

    private synchronized void logString(int i, String str, Object... objArr) {
        logString(i, str, null, false, objArr);
    }

    private void logString(int i, String str, String str2, boolean z, Object... objArr) {
        if (!z || TextUtils.isEmpty(str2)) {
            str2 = generateTag();
        }
        if (!z) {
            if (objArr != null && objArr.length > 0) {
                try {
                    str = String.format(str, objArr);
                } catch (IllegalFormatConversionException | MissingFormatArgumentException | UnknownFormatConversionException e) {
                    printLog(5, str2, Log.getStackTraceString(e));
                }
            }
            writeToFile(str2, str, i);
        }
        if (!this.mLogConfig.isEnable() || i < this.mLogConfig.getLogLevel()) {
            return;
        }
        int i2 = 0;
        if (str.length() > 2800) {
            if (this.mLogConfig.isShowBorder()) {
                StringBuilder sb = new StringBuilder();
                sb.append(str2);
                String[] strArr = CHARACTER_TABLE;
                sb.append(strArr[0]);
                printLog(i, sb.toString(), Utils.printDividingLine(1));
                printLog(i, str2 + strArr[1], Utils.printDividingLine(3) + getTopStackInfo());
                printLog(i, str2 + strArr[2], Utils.printDividingLine(4));
            }
            Iterator<String> it2 = ObjectUtil.largeStringToList(str).iterator();
            while (it2.hasNext()) {
                logString(i, it2.next(), str2, true, objArr);
            }
            if (this.mLogConfig.isShowBorder()) {
                printLog(i, str2 + CHARACTER_TABLE[4], Utils.printDividingLine(2));
                return;
            }
            return;
        }
        if (!this.mLogConfig.isShowBorder()) {
            printLog(i, str2, str);
            return;
        }
        if (z) {
            String[] split = str.split(Parser.LINE_SEPARATOR);
            int length = split.length;
            while (i2 < length) {
                String str3 = split[i2];
                printLog(i, str2 + CHARACTER_TABLE[3], Utils.printDividingLine(3) + str3);
                i2++;
            }
            return;
        }
        StringBuilder sb2 = new StringBuilder();
        sb2.append(str2);
        String[] strArr2 = CHARACTER_TABLE;
        sb2.append(strArr2[0]);
        printLog(i, sb2.toString(), Utils.printDividingLine(1));
        printLog(i, str2 + strArr2[1], Utils.printDividingLine(3) + getTopStackInfo());
        printLog(i, str2 + strArr2[2], Utils.printDividingLine(4));
        String[] split2 = str.split(Parser.LINE_SEPARATOR);
        int length2 = split2.length;
        while (i2 < length2) {
            String str4 = split2[i2];
            printLog(i, str2 + CHARACTER_TABLE[3], Utils.printDividingLine(3) + str4);
            i2++;
        }
        printLog(i, str2 + CHARACTER_TABLE[4], Utils.printDividingLine(2));
    }

    private void logObject(int i, Object obj) {
        logString(i, ObjectUtil.objectToString(obj), new Object[0]);
    }

    private String generateTag() {
        String str = this.localTags.get();
        if (!TextUtils.isEmpty(str)) {
            this.localTags.remove();
            return str;
        }
        return this.mLogConfig.getTagPrefix();
    }

    private StackTraceElement getCurrentStackTrace() {
        int methodOffset;
        StackTraceElement[] stackTrace = Thread.currentThread().getStackTrace();
        int stackOffset = getStackOffset(stackTrace, LogUtils.class);
        if (stackOffset == -1 && (stackOffset = getStackOffset(stackTrace, Logger.class)) == -1) {
            return null;
        }
        if (this.mLogConfig.getMethodOffset() > 0 && (methodOffset = this.mLogConfig.getMethodOffset() + stackOffset) < stackTrace.length) {
            stackOffset = methodOffset;
        }
        return stackTrace[stackOffset];
    }

    private String getTopStackInfo() {
        String formatTag = this.mLogConfig.getFormatTag(getCurrentStackTrace());
        if (formatTag != null) {
            return formatTag;
        }
        StackTraceElement currentStackTrace = getCurrentStackTrace();
        String stackTraceElement = currentStackTrace.toString();
        String substring = stackTraceElement.substring(stackTraceElement.lastIndexOf(40), stackTraceElement.length());
        String className = currentStackTrace.getClassName();
        return String.format("%s.%s%s", className.substring(className.lastIndexOf(".") + 1), currentStackTrace.getMethodName(), substring);
    }

    private int getStackOffset(StackTraceElement[] stackTraceElementArr, Class cls) {
        for (int i = 5; i < stackTraceElementArr.length; i++) {
            String className = stackTraceElementArr[i].getClassName();
            if (!(cls.equals(Logger.class) && i < stackTraceElementArr.length - 1 && stackTraceElementArr[i + 1].getClassName().equals(Logger.class.getName())) && className.equals(cls.getName())) {
                return i + 1;
            }
        }
        return -1;
    }

    @Override // com.apkfuns.logutils.Printer
    public void d(String str, Object... objArr) {
        logString(2, str, objArr);
    }

    @Override // com.apkfuns.logutils.Printer
    public void d(Object obj) {
        logObject(2, obj);
    }

    @Override // com.apkfuns.logutils.Printer
    public void e(String str, Object... objArr) {
        logString(5, str, objArr);
    }

    @Override // com.apkfuns.logutils.Printer
    public void e(Object obj) {
        logObject(5, obj);
    }

    @Override // com.apkfuns.logutils.Printer
    public void w(String str, Object... objArr) {
        logString(4, str, objArr);
    }

    @Override // com.apkfuns.logutils.Printer
    public void w(Object obj) {
        logObject(4, obj);
    }

    @Override // com.apkfuns.logutils.Printer
    public void i(String str, Object... objArr) {
        logString(3, str, objArr);
    }

    @Override // com.apkfuns.logutils.Printer
    public void i(Object obj) {
        logObject(3, obj);
    }

    @Override // com.apkfuns.logutils.Printer
    public void v(String str, Object... objArr) {
        logString(1, str, objArr);
    }

    @Override // com.apkfuns.logutils.Printer
    public void v(Object obj) {
        logObject(1, obj);
    }

    @Override // com.apkfuns.logutils.Printer
    public void wtf(String str, Object... objArr) {
        logString(6, str, objArr);
    }

    @Override // com.apkfuns.logutils.Printer
    public void wtf(Object obj) {
        logObject(6, obj);
    }

    @Override // com.apkfuns.logutils.Printer
    public void json(String str) {
        if (TextUtils.isEmpty(str)) {
            i("JSON{json is empty}");
            return;
        }
        try {
            if (str.startsWith("{")) {
                i(new JSONObject(str).toString(4));
            } else if (str.startsWith("[")) {
                i(new JSONArray(str).toString(4));
            }
        } catch (JSONException e) {
            e(e.toString() + "\n\njson = " + str);
        }
    }

    @Override // com.apkfuns.logutils.Printer
    public void xml(String str) {
        if (TextUtils.isEmpty(str)) {
            i("XML{xml is empty}");
            return;
        }
        try {
            StreamSource streamSource = new StreamSource(new StringReader(str));
            StreamResult streamResult = new StreamResult(new StringWriter());
            Transformer newTransformer = TransformerFactory.newInstance().newTransformer();
            newTransformer.setOutputProperty("indent", "yes");
            newTransformer.setOutputProperty("{http://xml.apache.org/xslt}indent-amount", "2");
            newTransformer.transform(streamSource, streamResult);
            i(streamResult.getWriter().toString().replaceFirst(">", ">\n"));
        } catch (TransformerException e) {
            e(e.toString() + "\n\nxml = " + str);
        }
    }

    private void printLog(int i, String str, String str2) {
        if (!this.mLogConfig.isShowBorder()) {
            str2 = getTopStackInfo() + ": " + str2;
        }
        switch (i) {
            case 1:
                Log.v(str, str2);
                break;
            case 2:
                Log.d(str, str2);
                break;
            case 3:
                Log.i(str, str2);
                break;
            case 4:
                Log.w(str, str2);
                break;
            case 5:
                Log.e(str, str2);
                break;
            case 6:
                Log.wtf(str, str2);
                break;
        }
    }

    private void writeToFile(String str, String str2, int i) {
        if (this.log2FileConfig.isEnable()) {
            if ((this.log2FileConfig.getFileFilter() == null || this.log2FileConfig.getFileFilter().accept(i, str, str2)) && i >= this.log2FileConfig.getLogLevel()) {
                File file = new File(this.log2FileConfig.getLogPath(), this.log2FileConfig.getLogFormatName());
                if (this.log2FileConfig.getEngine() != null) {
                    this.log2FileConfig.getEngine().writeToFile(file, str2, new LogFileParam(System.currentTimeMillis(), i, Thread.currentThread().getName(), str));
                    return;
                }
                throw new IllegalArgumentException("LogFileEngine must not Null");
            }
        }
    }
}
