package com.facebook;

import android.app.AlarmManager;
import android.app.PendingIntent;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.util.Log;
import androidx.core.app.NotificationCompat;
import androidx.localbroadcastmanager.content.LocalBroadcastManager;
import com.facebook.AccessToken;
import com.facebook.GraphRequest;
import com.facebook.GraphRequestBatch;
import com.facebook.internal.NativeProtocol;
import com.facebook.internal.Utility;
import com.facebook.internal.Validate;
import com.facebook.internal.instrument.crashshield.CrashShieldHandler;
import java.util.Date;
import java.util.HashSet;
import java.util.Locale;
import java.util.Set;
import java.util.concurrent.atomic.AtomicBoolean;
import org.json.JSONArray;
import org.json.JSONObject;

/* loaded from: classes.dex */
public final class AccessTokenManager {
    public static final String ACTION_CURRENT_ACCESS_TOKEN_CHANGED = "com.facebook.sdk.ACTION_CURRENT_ACCESS_TOKEN_CHANGED";
    public static final String EXTRA_NEW_ACCESS_TOKEN = "com.facebook.sdk.EXTRA_NEW_ACCESS_TOKEN";
    public static final String EXTRA_OLD_ACCESS_TOKEN = "com.facebook.sdk.EXTRA_OLD_ACCESS_TOKEN";
    private static final String ME_PERMISSIONS_GRAPH_PATH = "me/permissions";
    public static final String SHARED_PREFERENCES_NAME = "com.facebook.AccessTokenManager.SharedPreferences";
    public static final String TAG = "AccessTokenManager";
    private static final String TOKEN_EXTEND_GRAPH_PATH = "oauth/access_token";
    private static final int TOKEN_EXTEND_RETRY_SECONDS = 3600;
    private static final int TOKEN_EXTEND_THRESHOLD_SECONDS = 86400;
    private static volatile AccessTokenManager instance;
    private final AccessTokenCache accessTokenCache;
    private AccessToken currentAccessToken;
    private final LocalBroadcastManager localBroadcastManager;
    private AtomicBoolean tokenRefreshInProgress = new AtomicBoolean(false);
    private Date lastAttemptedTokenExtendDate = new Date(0);

    AccessTokenManager(LocalBroadcastManager localBroadcastManager, AccessTokenCache accessTokenCache) {
        Validate.notNull(localBroadcastManager, "localBroadcastManager");
        Validate.notNull(accessTokenCache, "accessTokenCache");
        this.localBroadcastManager = localBroadcastManager;
        this.accessTokenCache = accessTokenCache;
    }

    static AccessTokenManager getInstance() {
        if (instance == null) {
            synchronized (AccessTokenManager.class) {
                if (instance == null) {
                    instance = new AccessTokenManager(LocalBroadcastManager.getInstance(FacebookSdk.getApplicationContext()), new AccessTokenCache());
                }
            }
        }
        return instance;
    }

    AccessToken getCurrentAccessToken() {
        return this.currentAccessToken;
    }

    boolean loadCurrentAccessToken() {
        AccessToken load = this.accessTokenCache.load();
        if (load == null) {
            return false;
        }
        setCurrentAccessToken(load, false);
        return true;
    }

    void setCurrentAccessToken(AccessToken accessToken) {
        setCurrentAccessToken(accessToken, true);
    }

    private void setCurrentAccessToken(AccessToken accessToken, boolean z) {
        AccessToken accessToken2 = this.currentAccessToken;
        this.currentAccessToken = accessToken;
        this.tokenRefreshInProgress.set(false);
        this.lastAttemptedTokenExtendDate = new Date(0L);
        if (z) {
            if (accessToken != null) {
                this.accessTokenCache.save(accessToken);
            } else {
                this.accessTokenCache.clear();
                Utility.clearFacebookCookies(FacebookSdk.getApplicationContext());
            }
        }
        if (Utility.areObjectsEqual(accessToken2, accessToken)) {
            return;
        }
        sendCurrentAccessTokenChangedBroadcastIntent(accessToken2, accessToken);
        setTokenExpirationBroadcastAlarm();
    }

    void currentAccessTokenChanged() {
        AccessToken accessToken = this.currentAccessToken;
        sendCurrentAccessTokenChangedBroadcastIntent(accessToken, accessToken);
    }

    private void sendCurrentAccessTokenChangedBroadcastIntent(AccessToken accessToken, AccessToken accessToken2) {
        Intent intent = new Intent(FacebookSdk.getApplicationContext(), (Class<?>) CurrentAccessTokenExpirationBroadcastReceiver.class);
        intent.setAction(ACTION_CURRENT_ACCESS_TOKEN_CHANGED);
        intent.putExtra(EXTRA_OLD_ACCESS_TOKEN, accessToken);
        intent.putExtra(EXTRA_NEW_ACCESS_TOKEN, accessToken2);
        this.localBroadcastManager.sendBroadcast(intent);
    }

    private void setTokenExpirationBroadcastAlarm() {
        Context applicationContext = FacebookSdk.getApplicationContext();
        AccessToken currentAccessToken = AccessToken.getCurrentAccessToken();
        AlarmManager alarmManager = (AlarmManager) applicationContext.getSystemService(NotificationCompat.CATEGORY_ALARM);
        if (!AccessToken.isCurrentAccessTokenActive() || currentAccessToken.getExpires() == null || alarmManager == null) {
            return;
        }
        Intent intent = new Intent(applicationContext, (Class<?>) CurrentAccessTokenExpirationBroadcastReceiver.class);
        intent.setAction(ACTION_CURRENT_ACCESS_TOKEN_CHANGED);
        try {
            alarmManager.set(1, currentAccessToken.getExpires().getTime(), PendingIntent.getBroadcast(applicationContext, 0, intent, 0));
        } catch (Exception unused) {
        }
    }

    void extendAccessTokenIfNeeded() {
        if (shouldExtendAccessToken()) {
            refreshCurrentAccessToken(null);
        }
    }

    private boolean shouldExtendAccessToken() {
        if (this.currentAccessToken == null) {
            return false;
        }
        Long valueOf = Long.valueOf(new Date().getTime());
        return this.currentAccessToken.getSource().canExtendToken() && valueOf.longValue() - this.lastAttemptedTokenExtendDate.getTime() > 3600000 && valueOf.longValue() - this.currentAccessToken.getLastRefresh().getTime() > 86400000;
    }

    private static GraphRequest createGrantedPermissionsRequest(AccessToken accessToken, GraphRequest.Callback callback) {
        return new GraphRequest(accessToken, ME_PERMISSIONS_GRAPH_PATH, new Bundle(), HttpMethod.GET, callback);
    }

    private static GraphRequest createExtendAccessTokenRequest(AccessToken accessToken, GraphRequest.Callback callback) {
        Bundle bundle = new Bundle();
        bundle.putString("grant_type", "fb_extend_sso_token");
        bundle.putString("client_id", accessToken.getApplicationId());
        return new GraphRequest(accessToken, TOKEN_EXTEND_GRAPH_PATH, bundle, HttpMethod.GET, callback);
    }

    private static class RefreshResult {
        public String accessToken;
        public Long dataAccessExpirationTime;
        public int expiresAt;
        public String graphDomain;

        private RefreshResult() {
        }

        /* synthetic */ RefreshResult(AnonymousClass1 anonymousClass1) {
            this();
        }
    }

    void refreshCurrentAccessToken(AccessToken.AccessTokenRefreshCallback accessTokenRefreshCallback) {
        if (Looper.getMainLooper().equals(Looper.myLooper())) {
            refreshCurrentAccessTokenImpl(accessTokenRefreshCallback);
        } else {
            new Handler(Looper.getMainLooper()).post(new Runnable() { // from class: com.facebook.AccessTokenManager.1
                final /* synthetic */ AccessToken.AccessTokenRefreshCallback val$callback;

                AnonymousClass1(AccessToken.AccessTokenRefreshCallback accessTokenRefreshCallback2) {
                    r2 = accessTokenRefreshCallback2;
                }

                @Override // java.lang.Runnable
                public void run() {
                    if (CrashShieldHandler.isObjectCrashing(this)) {
                        return;
                    }
                    try {
                        AccessTokenManager.this.refreshCurrentAccessTokenImpl(r2);
                    } catch (Throwable th) {
                        CrashShieldHandler.handleThrowable(th, this);
                    }
                }
            });
        }
    }

    /* renamed from: com.facebook.AccessTokenManager$1 */
    class AnonymousClass1 implements Runnable {
        final /* synthetic */ AccessToken.AccessTokenRefreshCallback val$callback;

        AnonymousClass1(AccessToken.AccessTokenRefreshCallback accessTokenRefreshCallback2) {
            r2 = accessTokenRefreshCallback2;
        }

        @Override // java.lang.Runnable
        public void run() {
            if (CrashShieldHandler.isObjectCrashing(this)) {
                return;
            }
            try {
                AccessTokenManager.this.refreshCurrentAccessTokenImpl(r2);
            } catch (Throwable th) {
                CrashShieldHandler.handleThrowable(th, this);
            }
        }
    }

    public void refreshCurrentAccessTokenImpl(AccessToken.AccessTokenRefreshCallback accessTokenRefreshCallback) {
        AccessToken accessToken = this.currentAccessToken;
        if (accessToken == null) {
            if (accessTokenRefreshCallback != null) {
                accessTokenRefreshCallback.OnTokenRefreshFailed(new FacebookException("No current access token to refresh"));
            }
        } else {
            if (!this.tokenRefreshInProgress.compareAndSet(false, true)) {
                if (accessTokenRefreshCallback != null) {
                    accessTokenRefreshCallback.OnTokenRefreshFailed(new FacebookException("Refresh already in progress"));
                    return;
                }
                return;
            }
            this.lastAttemptedTokenExtendDate = new Date();
            HashSet hashSet = new HashSet();
            HashSet hashSet2 = new HashSet();
            HashSet hashSet3 = new HashSet();
            AtomicBoolean atomicBoolean = new AtomicBoolean(false);
            RefreshResult refreshResult = new RefreshResult();
            GraphRequestBatch graphRequestBatch = new GraphRequestBatch(createGrantedPermissionsRequest(accessToken, new GraphRequest.Callback() { // from class: com.facebook.AccessTokenManager.2
                final /* synthetic */ Set val$declinedPermissions;
                final /* synthetic */ Set val$expiredPermissions;
                final /* synthetic */ Set val$permissions;
                final /* synthetic */ AtomicBoolean val$permissionsCallSucceeded;

                AnonymousClass2(AtomicBoolean atomicBoolean2, Set hashSet4, Set hashSet22, Set hashSet32) {
                    r2 = atomicBoolean2;
                    r3 = hashSet4;
                    r4 = hashSet22;
                    r5 = hashSet32;
                }

                @Override // com.facebook.GraphRequest.Callback
                public void onCompleted(GraphResponse graphResponse) {
                    JSONArray optJSONArray;
                    JSONObject jSONObject = graphResponse.getJSONObject();
                    if (jSONObject == null || (optJSONArray = jSONObject.optJSONArray("data")) == null) {
                        return;
                    }
                    r2.set(true);
                    for (int i = 0; i < optJSONArray.length(); i++) {
                        JSONObject optJSONObject = optJSONArray.optJSONObject(i);
                        if (optJSONObject != null) {
                            String optString = optJSONObject.optString("permission");
                            String optString2 = optJSONObject.optString("status");
                            if (!Utility.isNullOrEmpty(optString) && !Utility.isNullOrEmpty(optString2)) {
                                String lowerCase = optString2.toLowerCase(Locale.US);
                                if (lowerCase.equals("granted")) {
                                    r3.add(optString);
                                } else if (lowerCase.equals("declined")) {
                                    r4.add(optString);
                                } else if (lowerCase.equals("expired")) {
                                    r5.add(optString);
                                } else {
                                    Log.w(AccessTokenManager.TAG, "Unexpected status: " + lowerCase);
                                }
                            }
                        }
                    }
                }
            }), createExtendAccessTokenRequest(accessToken, new GraphRequest.Callback() { // from class: com.facebook.AccessTokenManager.3
                final /* synthetic */ RefreshResult val$refreshResult;

                AnonymousClass3(RefreshResult refreshResult2) {
                    r2 = refreshResult2;
                }

                @Override // com.facebook.GraphRequest.Callback
                public void onCompleted(GraphResponse graphResponse) {
                    JSONObject jSONObject = graphResponse.getJSONObject();
                    if (jSONObject == null) {
                        return;
                    }
                    r2.accessToken = jSONObject.optString("access_token");
                    r2.expiresAt = jSONObject.optInt("expires_at");
                    r2.dataAccessExpirationTime = Long.valueOf(jSONObject.optLong(AccessToken.DATA_ACCESS_EXPIRATION_TIME));
                    r2.graphDomain = jSONObject.optString(NativeProtocol.RESULT_ARGS_GRAPH_DOMAIN, null);
                }
            }));
            graphRequestBatch.addCallback(new GraphRequestBatch.Callback() { // from class: com.facebook.AccessTokenManager.4
                final /* synthetic */ AccessToken val$accessToken;
                final /* synthetic */ AccessToken.AccessTokenRefreshCallback val$callback;
                final /* synthetic */ Set val$declinedPermissions;
                final /* synthetic */ Set val$expiredPermissions;
                final /* synthetic */ Set val$permissions;
                final /* synthetic */ AtomicBoolean val$permissionsCallSucceeded;
                final /* synthetic */ RefreshResult val$refreshResult;

                AnonymousClass4(AccessToken accessToken2, AccessToken.AccessTokenRefreshCallback accessTokenRefreshCallback2, AtomicBoolean atomicBoolean2, RefreshResult refreshResult2, Set hashSet4, Set hashSet22, Set hashSet32) {
                    r2 = accessToken2;
                    r3 = accessTokenRefreshCallback2;
                    r4 = atomicBoolean2;
                    r5 = refreshResult2;
                    r6 = hashSet4;
                    r7 = hashSet22;
                    r8 = hashSet32;
                }

                @Override // com.facebook.GraphRequestBatch.Callback
                public void onBatchCompleted(GraphRequestBatch graphRequestBatch2) {
                    AccessToken accessToken2;
                    Date dataAccessExpirationTime;
                    try {
                        if (AccessTokenManager.getInstance().getCurrentAccessToken() != null && AccessTokenManager.getInstance().getCurrentAccessToken().getUserId() == r2.getUserId()) {
                            if (!r4.get() && r5.accessToken == null && r5.expiresAt == 0) {
                                AccessToken.AccessTokenRefreshCallback accessTokenRefreshCallback2 = r3;
                                if (accessTokenRefreshCallback2 != null) {
                                    accessTokenRefreshCallback2.OnTokenRefreshFailed(new FacebookException("Failed to refresh access token"));
                                }
                                AccessTokenManager.this.tokenRefreshInProgress.set(false);
                                return;
                            }
                            String token = r5.accessToken != null ? r5.accessToken : r2.getToken();
                            String applicationId = r2.getApplicationId();
                            String userId = r2.getUserId();
                            Set<String> permissions = r4.get() ? r6 : r2.getPermissions();
                            Set<String> declinedPermissions = r4.get() ? r7 : r2.getDeclinedPermissions();
                            Set<String> expiredPermissions = r4.get() ? r8 : r2.getExpiredPermissions();
                            AccessTokenSource source = r2.getSource();
                            Date date = r5.expiresAt != 0 ? new Date(r5.expiresAt * 1000) : r2.getExpires();
                            Date date2 = new Date();
                            if (r5.dataAccessExpirationTime != null) {
                                dataAccessExpirationTime = new Date(1000 * r5.dataAccessExpirationTime.longValue());
                            } else {
                                dataAccessExpirationTime = r2.getDataAccessExpirationTime();
                            }
                            accessToken2 = r15;
                            AccessToken accessToken3 = new AccessToken(token, applicationId, userId, permissions, declinedPermissions, expiredPermissions, source, date, date2, dataAccessExpirationTime, r5.graphDomain);
                            try {
                                AccessTokenManager.getInstance().setCurrentAccessToken(accessToken2);
                                AccessTokenManager.this.tokenRefreshInProgress.set(false);
                                AccessToken.AccessTokenRefreshCallback accessTokenRefreshCallback3 = r3;
                                if (accessTokenRefreshCallback3 != null) {
                                    accessTokenRefreshCallback3.OnTokenRefreshed(accessToken2);
                                    return;
                                }
                                return;
                            } catch (Throwable th) {
                                th = th;
                                AccessTokenManager.this.tokenRefreshInProgress.set(false);
                                AccessToken.AccessTokenRefreshCallback accessTokenRefreshCallback4 = r3;
                                if (accessTokenRefreshCallback4 != null && accessToken2 != null) {
                                    accessTokenRefreshCallback4.OnTokenRefreshed(accessToken2);
                                }
                                throw th;
                            }
                        }
                        AccessToken.AccessTokenRefreshCallback accessTokenRefreshCallback5 = r3;
                        if (accessTokenRefreshCallback5 != null) {
                            accessTokenRefreshCallback5.OnTokenRefreshFailed(new FacebookException("No current access token to refresh"));
                        }
                        AccessTokenManager.this.tokenRefreshInProgress.set(false);
                    } catch (Throwable th2) {
                        th = th2;
                        accessToken2 = null;
                    }
                }
            });
            graphRequestBatch.executeAsync();
        }
    }

    /* renamed from: com.facebook.AccessTokenManager$2 */
    class AnonymousClass2 implements GraphRequest.Callback {
        final /* synthetic */ Set val$declinedPermissions;
        final /* synthetic */ Set val$expiredPermissions;
        final /* synthetic */ Set val$permissions;
        final /* synthetic */ AtomicBoolean val$permissionsCallSucceeded;

        AnonymousClass2(AtomicBoolean atomicBoolean2, Set hashSet4, Set hashSet22, Set hashSet32) {
            r2 = atomicBoolean2;
            r3 = hashSet4;
            r4 = hashSet22;
            r5 = hashSet32;
        }

        @Override // com.facebook.GraphRequest.Callback
        public void onCompleted(GraphResponse graphResponse) {
            JSONArray optJSONArray;
            JSONObject jSONObject = graphResponse.getJSONObject();
            if (jSONObject == null || (optJSONArray = jSONObject.optJSONArray("data")) == null) {
                return;
            }
            r2.set(true);
            for (int i = 0; i < optJSONArray.length(); i++) {
                JSONObject optJSONObject = optJSONArray.optJSONObject(i);
                if (optJSONObject != null) {
                    String optString = optJSONObject.optString("permission");
                    String optString2 = optJSONObject.optString("status");
                    if (!Utility.isNullOrEmpty(optString) && !Utility.isNullOrEmpty(optString2)) {
                        String lowerCase = optString2.toLowerCase(Locale.US);
                        if (lowerCase.equals("granted")) {
                            r3.add(optString);
                        } else if (lowerCase.equals("declined")) {
                            r4.add(optString);
                        } else if (lowerCase.equals("expired")) {
                            r5.add(optString);
                        } else {
                            Log.w(AccessTokenManager.TAG, "Unexpected status: " + lowerCase);
                        }
                    }
                }
            }
        }
    }

    /* renamed from: com.facebook.AccessTokenManager$3 */
    class AnonymousClass3 implements GraphRequest.Callback {
        final /* synthetic */ RefreshResult val$refreshResult;

        AnonymousClass3(RefreshResult refreshResult2) {
            r2 = refreshResult2;
        }

        @Override // com.facebook.GraphRequest.Callback
        public void onCompleted(GraphResponse graphResponse) {
            JSONObject jSONObject = graphResponse.getJSONObject();
            if (jSONObject == null) {
                return;
            }
            r2.accessToken = jSONObject.optString("access_token");
            r2.expiresAt = jSONObject.optInt("expires_at");
            r2.dataAccessExpirationTime = Long.valueOf(jSONObject.optLong(AccessToken.DATA_ACCESS_EXPIRATION_TIME));
            r2.graphDomain = jSONObject.optString(NativeProtocol.RESULT_ARGS_GRAPH_DOMAIN, null);
        }
    }

    /* renamed from: com.facebook.AccessTokenManager$4 */
    class AnonymousClass4 implements GraphRequestBatch.Callback {
        final /* synthetic */ AccessToken val$accessToken;
        final /* synthetic */ AccessToken.AccessTokenRefreshCallback val$callback;
        final /* synthetic */ Set val$declinedPermissions;
        final /* synthetic */ Set val$expiredPermissions;
        final /* synthetic */ Set val$permissions;
        final /* synthetic */ AtomicBoolean val$permissionsCallSucceeded;
        final /* synthetic */ RefreshResult val$refreshResult;

        AnonymousClass4(AccessToken accessToken2, AccessToken.AccessTokenRefreshCallback accessTokenRefreshCallback2, AtomicBoolean atomicBoolean2, RefreshResult refreshResult2, Set hashSet4, Set hashSet22, Set hashSet32) {
            r2 = accessToken2;
            r3 = accessTokenRefreshCallback2;
            r4 = atomicBoolean2;
            r5 = refreshResult2;
            r6 = hashSet4;
            r7 = hashSet22;
            r8 = hashSet32;
        }

        @Override // com.facebook.GraphRequestBatch.Callback
        public void onBatchCompleted(GraphRequestBatch graphRequestBatch2) {
            AccessToken accessToken2;
            Date dataAccessExpirationTime;
            try {
                if (AccessTokenManager.getInstance().getCurrentAccessToken() != null && AccessTokenManager.getInstance().getCurrentAccessToken().getUserId() == r2.getUserId()) {
                    if (!r4.get() && r5.accessToken == null && r5.expiresAt == 0) {
                        AccessToken.AccessTokenRefreshCallback accessTokenRefreshCallback2 = r3;
                        if (accessTokenRefreshCallback2 != null) {
                            accessTokenRefreshCallback2.OnTokenRefreshFailed(new FacebookException("Failed to refresh access token"));
                        }
                        AccessTokenManager.this.tokenRefreshInProgress.set(false);
                        return;
                    }
                    String token = r5.accessToken != null ? r5.accessToken : r2.getToken();
                    String applicationId = r2.getApplicationId();
                    String userId = r2.getUserId();
                    Set<String> permissions = r4.get() ? r6 : r2.getPermissions();
                    Set<String> declinedPermissions = r4.get() ? r7 : r2.getDeclinedPermissions();
                    Set<String> expiredPermissions = r4.get() ? r8 : r2.getExpiredPermissions();
                    AccessTokenSource source = r2.getSource();
                    Date date = r5.expiresAt != 0 ? new Date(r5.expiresAt * 1000) : r2.getExpires();
                    Date date2 = new Date();
                    if (r5.dataAccessExpirationTime != null) {
                        dataAccessExpirationTime = new Date(1000 * r5.dataAccessExpirationTime.longValue());
                    } else {
                        dataAccessExpirationTime = r2.getDataAccessExpirationTime();
                    }
                    accessToken2 = accessToken3;
                    AccessToken accessToken3 = new AccessToken(token, applicationId, userId, permissions, declinedPermissions, expiredPermissions, source, date, date2, dataAccessExpirationTime, r5.graphDomain);
                    try {
                        AccessTokenManager.getInstance().setCurrentAccessToken(accessToken2);
                        AccessTokenManager.this.tokenRefreshInProgress.set(false);
                        AccessToken.AccessTokenRefreshCallback accessTokenRefreshCallback3 = r3;
                        if (accessTokenRefreshCallback3 != null) {
                            accessTokenRefreshCallback3.OnTokenRefreshed(accessToken2);
                            return;
                        }
                        return;
                    } catch (Throwable th) {
                        th = th;
                        AccessTokenManager.this.tokenRefreshInProgress.set(false);
                        AccessToken.AccessTokenRefreshCallback accessTokenRefreshCallback4 = r3;
                        if (accessTokenRefreshCallback4 != null && accessToken2 != null) {
                            accessTokenRefreshCallback4.OnTokenRefreshed(accessToken2);
                        }
                        throw th;
                    }
                }
                AccessToken.AccessTokenRefreshCallback accessTokenRefreshCallback5 = r3;
                if (accessTokenRefreshCallback5 != null) {
                    accessTokenRefreshCallback5.OnTokenRefreshFailed(new FacebookException("No current access token to refresh"));
                }
                AccessTokenManager.this.tokenRefreshInProgress.set(false);
            } catch (Throwable th2) {
                th = th2;
                accessToken2 = null;
            }
        }
    }
}
