package com.inuker.bluetooth.library;

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import android.os.Bundle;
import android.os.Handler;
import android.os.HandlerThread;
import android.os.IBinder;
import android.os.Looper;
import android.os.Message;
import com.inuker.bluetooth.library.IBluetoothService;
import com.inuker.bluetooth.library.connect.listener.BleConnectStatusListener;
import com.inuker.bluetooth.library.connect.listener.BluetoothStateListener;
import com.inuker.bluetooth.library.connect.options.BleConnectOptions;
import com.inuker.bluetooth.library.connect.response.BleConnectResponse;
import com.inuker.bluetooth.library.connect.response.BleMtuResponse;
import com.inuker.bluetooth.library.connect.response.BleNotifyResponse;
import com.inuker.bluetooth.library.connect.response.BleReadResponse;
import com.inuker.bluetooth.library.connect.response.BleReadRssiResponse;
import com.inuker.bluetooth.library.connect.response.BleUnnotifyResponse;
import com.inuker.bluetooth.library.connect.response.BleWriteResponse;
import com.inuker.bluetooth.library.connect.response.BluetoothResponse;
import com.inuker.bluetooth.library.model.BleGattProfile;
import com.inuker.bluetooth.library.receiver.BluetoothReceiver;
import com.inuker.bluetooth.library.receiver.listener.BleCharacterChangeListener;
import com.inuker.bluetooth.library.receiver.listener.BleConnectStatusChangeListener;
import com.inuker.bluetooth.library.receiver.listener.BluetoothBondListener;
import com.inuker.bluetooth.library.receiver.listener.BluetoothBondStateChangeListener;
import com.inuker.bluetooth.library.receiver.listener.BluetoothStateChangeListener;
import com.inuker.bluetooth.library.search.SearchRequest;
import com.inuker.bluetooth.library.search.SearchResult;
import com.inuker.bluetooth.library.search.response.SearchResponse;
import com.inuker.bluetooth.library.utils.BluetoothLog;
import com.inuker.bluetooth.library.utils.ListUtils;
import com.inuker.bluetooth.library.utils.proxy.ProxyBulk;
import com.inuker.bluetooth.library.utils.proxy.ProxyInterceptor;
import com.inuker.bluetooth.library.utils.proxy.ProxyUtils;
import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.UUID;
import java.util.concurrent.CountDownLatch;

/* loaded from: classes2.dex */
public class BluetoothClientImpl implements IBluetoothClient, ProxyInterceptor, Handler.Callback {
    private static final int MSG_INVOKE_PROXY = 1;
    private static final int MSG_REG_RECEIVER = 2;
    private static final String TAG = "BluetoothClientImpl";
    private static volatile IBluetoothClient sInstance;
    private List<BluetoothBondListener> mBluetoothBondListeners;
    private volatile IBluetoothService mBluetoothService;
    private List<BluetoothStateListener> mBluetoothStateListeners;
    private HashMap<String, List<BleConnectStatusListener>> mConnectStatusListeners;
    private final ServiceConnection mConnection = new ServiceConnection() { // from class: com.inuker.bluetooth.library.BluetoothClientImpl.1
        AnonymousClass1() {
        }

        @Override // android.content.ServiceConnection
        public void onServiceConnected(ComponentName componentName, IBinder iBinder) {
            BluetoothClientImpl.this.mBluetoothService = IBluetoothService.Stub.asInterface(iBinder);
            BluetoothClientImpl.this.notifyBluetoothManagerReady();
        }

        @Override // android.content.ServiceConnection
        public void onServiceDisconnected(ComponentName componentName) {
            BluetoothClientImpl.this.mBluetoothService = null;
        }
    };
    private Context mContext;
    private CountDownLatch mCountDownLatch;
    private HashMap<String, HashMap<String, List<BleNotifyResponse>>> mNotifyResponses;
    private Handler mWorkerHandler;
    private HandlerThread mWorkerThread;

    private BluetoothClientImpl(Context context) {
        Context applicationContext = context.getApplicationContext();
        this.mContext = applicationContext;
        BluetoothContext.set(applicationContext);
        HandlerThread handlerThread = new HandlerThread(TAG);
        this.mWorkerThread = handlerThread;
        handlerThread.start();
        this.mWorkerHandler = new Handler(this.mWorkerThread.getLooper(), this);
        this.mNotifyResponses = new HashMap<>();
        this.mConnectStatusListeners = new HashMap<>();
        this.mBluetoothStateListeners = new LinkedList();
        this.mBluetoothBondListeners = new LinkedList();
        this.mWorkerHandler.obtainMessage(2).sendToTarget();
    }

    public static IBluetoothClient getInstance(Context context) {
        if (sInstance == null) {
            synchronized (BluetoothClientImpl.class) {
                if (sInstance == null) {
                    BluetoothClientImpl bluetoothClientImpl = new BluetoothClientImpl(context);
                    sInstance = (IBluetoothClient) ProxyUtils.getProxy(bluetoothClientImpl, IBluetoothClient.class, bluetoothClientImpl);
                }
            }
        }
        return sInstance;
    }

    private IBluetoothService getBluetoothService() {
        if (this.mBluetoothService == null) {
            bindServiceSync();
        }
        return this.mBluetoothService;
    }

    private void bindServiceSync() {
        checkRuntime(true);
        this.mCountDownLatch = new CountDownLatch(1);
        Intent intent = new Intent();
        intent.setClass(this.mContext, BluetoothService.class);
        if (this.mContext.bindService(intent, this.mConnection, 1)) {
            waitBluetoothManagerReady();
        } else {
            this.mBluetoothService = BluetoothServiceImpl.getInstance();
        }
    }

    /* renamed from: com.inuker.bluetooth.library.BluetoothClientImpl$1 */
    class AnonymousClass1 implements ServiceConnection {
        AnonymousClass1() {
        }

        @Override // android.content.ServiceConnection
        public void onServiceConnected(ComponentName componentName, IBinder iBinder) {
            BluetoothClientImpl.this.mBluetoothService = IBluetoothService.Stub.asInterface(iBinder);
            BluetoothClientImpl.this.notifyBluetoothManagerReady();
        }

        @Override // android.content.ServiceConnection
        public void onServiceDisconnected(ComponentName componentName) {
            BluetoothClientImpl.this.mBluetoothService = null;
        }
    }

    @Override // com.inuker.bluetooth.library.IBluetoothClient
    public void connect(String str, BleConnectOptions bleConnectOptions, BleConnectResponse bleConnectResponse) {
        Bundle bundle = new Bundle();
        bundle.putString(Constants.EXTRA_MAC, str);
        bundle.putParcelable(Constants.EXTRA_OPTIONS, bleConnectOptions);
        safeCallBluetoothApi(1, bundle, new BluetoothResponse() { // from class: com.inuker.bluetooth.library.BluetoothClientImpl.2
            final /* synthetic */ BleConnectResponse val$response;

            AnonymousClass2(BleConnectResponse bleConnectResponse2) {
                r2 = bleConnectResponse2;
            }

            @Override // com.inuker.bluetooth.library.connect.response.BluetoothResponse
            protected void onAsyncResponse(int i, Bundle bundle2) {
                BluetoothClientImpl.this.checkRuntime(true);
                if (r2 != null) {
                    bundle2.setClassLoader(getClass().getClassLoader());
                    r2.onResponse(i, (BleGattProfile) bundle2.getParcelable(Constants.EXTRA_GATT_PROFILE));
                }
            }
        });
    }

    /* renamed from: com.inuker.bluetooth.library.BluetoothClientImpl$2 */
    class AnonymousClass2 extends BluetoothResponse {
        final /* synthetic */ BleConnectResponse val$response;

        AnonymousClass2(BleConnectResponse bleConnectResponse2) {
            r2 = bleConnectResponse2;
        }

        @Override // com.inuker.bluetooth.library.connect.response.BluetoothResponse
        protected void onAsyncResponse(int i, Bundle bundle2) {
            BluetoothClientImpl.this.checkRuntime(true);
            if (r2 != null) {
                bundle2.setClassLoader(getClass().getClassLoader());
                r2.onResponse(i, (BleGattProfile) bundle2.getParcelable(Constants.EXTRA_GATT_PROFILE));
            }
        }
    }

    @Override // com.inuker.bluetooth.library.IBluetoothClient
    public void disconnect(String str) {
        Bundle bundle = new Bundle();
        bundle.putString(Constants.EXTRA_MAC, str);
        safeCallBluetoothApi(2, bundle, null);
        clearNotifyListener(str);
    }

    @Override // com.inuker.bluetooth.library.IBluetoothClient
    public void registerConnectStatusListener(String str, BleConnectStatusListener bleConnectStatusListener) {
        checkRuntime(true);
        List<BleConnectStatusListener> list = this.mConnectStatusListeners.get(str);
        if (list == null) {
            list = new ArrayList<>();
            this.mConnectStatusListeners.put(str, list);
        }
        if (bleConnectStatusListener == null || list.contains(bleConnectStatusListener)) {
            return;
        }
        list.add(bleConnectStatusListener);
    }

    @Override // com.inuker.bluetooth.library.IBluetoothClient
    public void unregisterConnectStatusListener(String str, BleConnectStatusListener bleConnectStatusListener) {
        checkRuntime(true);
        List<BleConnectStatusListener> list = this.mConnectStatusListeners.get(str);
        if (bleConnectStatusListener == null || ListUtils.isEmpty(list)) {
            return;
        }
        list.remove(bleConnectStatusListener);
    }

    @Override // com.inuker.bluetooth.library.IBluetoothClient
    public void read(String str, UUID uuid, UUID uuid2, BleReadResponse bleReadResponse) {
        Bundle bundle = new Bundle();
        bundle.putString(Constants.EXTRA_MAC, str);
        bundle.putSerializable(Constants.EXTRA_SERVICE_UUID, uuid);
        bundle.putSerializable(Constants.EXTRA_CHARACTER_UUID, uuid2);
        safeCallBluetoothApi(3, bundle, new BluetoothResponse() { // from class: com.inuker.bluetooth.library.BluetoothClientImpl.3
            final /* synthetic */ BleReadResponse val$response;

            AnonymousClass3(BleReadResponse bleReadResponse2) {
                r2 = bleReadResponse2;
            }

            @Override // com.inuker.bluetooth.library.connect.response.BluetoothResponse
            protected void onAsyncResponse(int i, Bundle bundle2) {
                BluetoothClientImpl.this.checkRuntime(true);
                BleReadResponse bleReadResponse2 = r2;
                if (bleReadResponse2 != null) {
                    bleReadResponse2.onResponse(i, bundle2.getByteArray(Constants.EXTRA_BYTE_VALUE));
                }
            }
        });
    }

    /* renamed from: com.inuker.bluetooth.library.BluetoothClientImpl$3 */
    class AnonymousClass3 extends BluetoothResponse {
        final /* synthetic */ BleReadResponse val$response;

        AnonymousClass3(BleReadResponse bleReadResponse2) {
            r2 = bleReadResponse2;
        }

        @Override // com.inuker.bluetooth.library.connect.response.BluetoothResponse
        protected void onAsyncResponse(int i, Bundle bundle2) {
            BluetoothClientImpl.this.checkRuntime(true);
            BleReadResponse bleReadResponse2 = r2;
            if (bleReadResponse2 != null) {
                bleReadResponse2.onResponse(i, bundle2.getByteArray(Constants.EXTRA_BYTE_VALUE));
            }
        }
    }

    @Override // com.inuker.bluetooth.library.IBluetoothClient
    public void write(String str, UUID uuid, UUID uuid2, byte[] bArr, BleWriteResponse bleWriteResponse) {
        Bundle bundle = new Bundle();
        bundle.putString(Constants.EXTRA_MAC, str);
        bundle.putSerializable(Constants.EXTRA_SERVICE_UUID, uuid);
        bundle.putSerializable(Constants.EXTRA_CHARACTER_UUID, uuid2);
        bundle.putByteArray(Constants.EXTRA_BYTE_VALUE, bArr);
        safeCallBluetoothApi(4, bundle, new BluetoothResponse() { // from class: com.inuker.bluetooth.library.BluetoothClientImpl.4
            final /* synthetic */ BleWriteResponse val$response;

            AnonymousClass4(BleWriteResponse bleWriteResponse2) {
                r2 = bleWriteResponse2;
            }

            @Override // com.inuker.bluetooth.library.connect.response.BluetoothResponse
            protected void onAsyncResponse(int i, Bundle bundle2) {
                BluetoothClientImpl.this.checkRuntime(true);
                BleWriteResponse bleWriteResponse2 = r2;
                if (bleWriteResponse2 != null) {
                    bleWriteResponse2.onResponse(i);
                }
            }
        });
    }

    /* renamed from: com.inuker.bluetooth.library.BluetoothClientImpl$4 */
    class AnonymousClass4 extends BluetoothResponse {
        final /* synthetic */ BleWriteResponse val$response;

        AnonymousClass4(BleWriteResponse bleWriteResponse2) {
            r2 = bleWriteResponse2;
        }

        @Override // com.inuker.bluetooth.library.connect.response.BluetoothResponse
        protected void onAsyncResponse(int i, Bundle bundle2) {
            BluetoothClientImpl.this.checkRuntime(true);
            BleWriteResponse bleWriteResponse2 = r2;
            if (bleWriteResponse2 != null) {
                bleWriteResponse2.onResponse(i);
            }
        }
    }

    @Override // com.inuker.bluetooth.library.IBluetoothClient
    public void readDescriptor(String str, UUID uuid, UUID uuid2, UUID uuid3, BleReadResponse bleReadResponse) {
        Bundle bundle = new Bundle();
        bundle.putString(Constants.EXTRA_MAC, str);
        bundle.putSerializable(Constants.EXTRA_SERVICE_UUID, uuid);
        bundle.putSerializable(Constants.EXTRA_CHARACTER_UUID, uuid2);
        bundle.putSerializable(Constants.EXTRA_DESCRIPTOR_UUID, uuid3);
        safeCallBluetoothApi(13, bundle, new BluetoothResponse() { // from class: com.inuker.bluetooth.library.BluetoothClientImpl.5
            final /* synthetic */ BleReadResponse val$response;

            AnonymousClass5(BleReadResponse bleReadResponse2) {
                r2 = bleReadResponse2;
            }

            @Override // com.inuker.bluetooth.library.connect.response.BluetoothResponse
            protected void onAsyncResponse(int i, Bundle bundle2) {
                BluetoothClientImpl.this.checkRuntime(true);
                BleReadResponse bleReadResponse2 = r2;
                if (bleReadResponse2 != null) {
                    bleReadResponse2.onResponse(i, bundle2.getByteArray(Constants.EXTRA_BYTE_VALUE));
                }
            }
        });
    }

    /* renamed from: com.inuker.bluetooth.library.BluetoothClientImpl$5 */
    class AnonymousClass5 extends BluetoothResponse {
        final /* synthetic */ BleReadResponse val$response;

        AnonymousClass5(BleReadResponse bleReadResponse2) {
            r2 = bleReadResponse2;
        }

        @Override // com.inuker.bluetooth.library.connect.response.BluetoothResponse
        protected void onAsyncResponse(int i, Bundle bundle2) {
            BluetoothClientImpl.this.checkRuntime(true);
            BleReadResponse bleReadResponse2 = r2;
            if (bleReadResponse2 != null) {
                bleReadResponse2.onResponse(i, bundle2.getByteArray(Constants.EXTRA_BYTE_VALUE));
            }
        }
    }

    @Override // com.inuker.bluetooth.library.IBluetoothClient
    public void writeDescriptor(String str, UUID uuid, UUID uuid2, UUID uuid3, byte[] bArr, BleWriteResponse bleWriteResponse) {
        Bundle bundle = new Bundle();
        bundle.putString(Constants.EXTRA_MAC, str);
        bundle.putSerializable(Constants.EXTRA_SERVICE_UUID, uuid);
        bundle.putSerializable(Constants.EXTRA_CHARACTER_UUID, uuid2);
        bundle.putSerializable(Constants.EXTRA_DESCRIPTOR_UUID, uuid3);
        bundle.putByteArray(Constants.EXTRA_BYTE_VALUE, bArr);
        safeCallBluetoothApi(14, bundle, new BluetoothResponse() { // from class: com.inuker.bluetooth.library.BluetoothClientImpl.6
            final /* synthetic */ BleWriteResponse val$response;

            AnonymousClass6(BleWriteResponse bleWriteResponse2) {
                r2 = bleWriteResponse2;
            }

            @Override // com.inuker.bluetooth.library.connect.response.BluetoothResponse
            protected void onAsyncResponse(int i, Bundle bundle2) {
                BluetoothClientImpl.this.checkRuntime(true);
                BleWriteResponse bleWriteResponse2 = r2;
                if (bleWriteResponse2 != null) {
                    bleWriteResponse2.onResponse(i);
                }
            }
        });
    }

    /* renamed from: com.inuker.bluetooth.library.BluetoothClientImpl$6 */
    class AnonymousClass6 extends BluetoothResponse {
        final /* synthetic */ BleWriteResponse val$response;

        AnonymousClass6(BleWriteResponse bleWriteResponse2) {
            r2 = bleWriteResponse2;
        }

        @Override // com.inuker.bluetooth.library.connect.response.BluetoothResponse
        protected void onAsyncResponse(int i, Bundle bundle2) {
            BluetoothClientImpl.this.checkRuntime(true);
            BleWriteResponse bleWriteResponse2 = r2;
            if (bleWriteResponse2 != null) {
                bleWriteResponse2.onResponse(i);
            }
        }
    }

    @Override // com.inuker.bluetooth.library.IBluetoothClient
    public void writeNoRsp(String str, UUID uuid, UUID uuid2, byte[] bArr, BleWriteResponse bleWriteResponse) {
        Bundle bundle = new Bundle();
        bundle.putString(Constants.EXTRA_MAC, str);
        bundle.putSerializable(Constants.EXTRA_SERVICE_UUID, uuid);
        bundle.putSerializable(Constants.EXTRA_CHARACTER_UUID, uuid2);
        bundle.putByteArray(Constants.EXTRA_BYTE_VALUE, bArr);
        safeCallBluetoothApi(5, bundle, new BluetoothResponse() { // from class: com.inuker.bluetooth.library.BluetoothClientImpl.7
            final /* synthetic */ BleWriteResponse val$response;

            AnonymousClass7(BleWriteResponse bleWriteResponse2) {
                r2 = bleWriteResponse2;
            }

            @Override // com.inuker.bluetooth.library.connect.response.BluetoothResponse
            protected void onAsyncResponse(int i, Bundle bundle2) {
                BluetoothClientImpl.this.checkRuntime(true);
                BleWriteResponse bleWriteResponse2 = r2;
                if (bleWriteResponse2 != null) {
                    bleWriteResponse2.onResponse(i);
                }
            }
        });
    }

    /* renamed from: com.inuker.bluetooth.library.BluetoothClientImpl$7 */
    class AnonymousClass7 extends BluetoothResponse {
        final /* synthetic */ BleWriteResponse val$response;

        AnonymousClass7(BleWriteResponse bleWriteResponse2) {
            r2 = bleWriteResponse2;
        }

        @Override // com.inuker.bluetooth.library.connect.response.BluetoothResponse
        protected void onAsyncResponse(int i, Bundle bundle2) {
            BluetoothClientImpl.this.checkRuntime(true);
            BleWriteResponse bleWriteResponse2 = r2;
            if (bleWriteResponse2 != null) {
                bleWriteResponse2.onResponse(i);
            }
        }
    }

    public void saveNotifyListener(String str, UUID uuid, UUID uuid2, BleNotifyResponse bleNotifyResponse) {
        checkRuntime(true);
        HashMap<String, List<BleNotifyResponse>> hashMap = this.mNotifyResponses.get(str);
        if (hashMap == null) {
            hashMap = new HashMap<>();
            this.mNotifyResponses.put(str, hashMap);
        }
        String generateCharacterKey = generateCharacterKey(uuid, uuid2);
        List<BleNotifyResponse> list = hashMap.get(generateCharacterKey);
        if (list == null) {
            list = new ArrayList<>();
            hashMap.put(generateCharacterKey, list);
        }
        list.add(bleNotifyResponse);
    }

    public void removeNotifyListener(String str, UUID uuid, UUID uuid2) {
        checkRuntime(true);
        HashMap<String, List<BleNotifyResponse>> hashMap = this.mNotifyResponses.get(str);
        if (hashMap != null) {
            hashMap.remove(generateCharacterKey(uuid, uuid2));
        }
    }

    public void clearNotifyListener(String str) {
        checkRuntime(true);
        this.mNotifyResponses.remove(str);
    }

    private String generateCharacterKey(UUID uuid, UUID uuid2) {
        return String.format("%s_%s", uuid, uuid2);
    }

    @Override // com.inuker.bluetooth.library.IBluetoothClient
    public void notify(String str, UUID uuid, UUID uuid2, BleNotifyResponse bleNotifyResponse) {
        Bundle bundle = new Bundle();
        bundle.putString(Constants.EXTRA_MAC, str);
        bundle.putSerializable(Constants.EXTRA_SERVICE_UUID, uuid);
        bundle.putSerializable(Constants.EXTRA_CHARACTER_UUID, uuid2);
        safeCallBluetoothApi(6, bundle, new BluetoothResponse() { // from class: com.inuker.bluetooth.library.BluetoothClientImpl.8
            final /* synthetic */ UUID val$character;
            final /* synthetic */ String val$mac;
            final /* synthetic */ BleNotifyResponse val$response;
            final /* synthetic */ UUID val$service;

            AnonymousClass8(BleNotifyResponse bleNotifyResponse2, String str2, UUID uuid3, UUID uuid22) {
                r2 = bleNotifyResponse2;
                r3 = str2;
                r4 = uuid3;
                r5 = uuid22;
            }

            @Override // com.inuker.bluetooth.library.connect.response.BluetoothResponse
            protected void onAsyncResponse(int i, Bundle bundle2) {
                BluetoothClientImpl.this.checkRuntime(true);
                BleNotifyResponse bleNotifyResponse2 = r2;
                if (bleNotifyResponse2 != null) {
                    if (i == 0) {
                        BluetoothClientImpl.this.saveNotifyListener(r3, r4, r5, bleNotifyResponse2);
                    }
                    r2.onResponse(i);
                }
            }
        });
    }

    /* renamed from: com.inuker.bluetooth.library.BluetoothClientImpl$8 */
    class AnonymousClass8 extends BluetoothResponse {
        final /* synthetic */ UUID val$character;
        final /* synthetic */ String val$mac;
        final /* synthetic */ BleNotifyResponse val$response;
        final /* synthetic */ UUID val$service;

        AnonymousClass8(BleNotifyResponse bleNotifyResponse2, String str2, UUID uuid3, UUID uuid22) {
            r2 = bleNotifyResponse2;
            r3 = str2;
            r4 = uuid3;
            r5 = uuid22;
        }

        @Override // com.inuker.bluetooth.library.connect.response.BluetoothResponse
        protected void onAsyncResponse(int i, Bundle bundle2) {
            BluetoothClientImpl.this.checkRuntime(true);
            BleNotifyResponse bleNotifyResponse2 = r2;
            if (bleNotifyResponse2 != null) {
                if (i == 0) {
                    BluetoothClientImpl.this.saveNotifyListener(r3, r4, r5, bleNotifyResponse2);
                }
                r2.onResponse(i);
            }
        }
    }

    @Override // com.inuker.bluetooth.library.IBluetoothClient
    public void unnotify(String str, UUID uuid, UUID uuid2, BleUnnotifyResponse bleUnnotifyResponse) {
        Bundle bundle = new Bundle();
        bundle.putString(Constants.EXTRA_MAC, str);
        bundle.putSerializable(Constants.EXTRA_SERVICE_UUID, uuid);
        bundle.putSerializable(Constants.EXTRA_CHARACTER_UUID, uuid2);
        safeCallBluetoothApi(7, bundle, new BluetoothResponse() { // from class: com.inuker.bluetooth.library.BluetoothClientImpl.9
            final /* synthetic */ UUID val$character;
            final /* synthetic */ String val$mac;
            final /* synthetic */ BleUnnotifyResponse val$response;
            final /* synthetic */ UUID val$service;

            AnonymousClass9(String str2, UUID uuid3, UUID uuid22, BleUnnotifyResponse bleUnnotifyResponse2) {
                r2 = str2;
                r3 = uuid3;
                r4 = uuid22;
                r5 = bleUnnotifyResponse2;
            }

            @Override // com.inuker.bluetooth.library.connect.response.BluetoothResponse
            protected void onAsyncResponse(int i, Bundle bundle2) {
                BluetoothClientImpl.this.checkRuntime(true);
                BluetoothClientImpl.this.removeNotifyListener(r2, r3, r4);
                BleUnnotifyResponse bleUnnotifyResponse2 = r5;
                if (bleUnnotifyResponse2 != null) {
                    bleUnnotifyResponse2.onResponse(i);
                }
            }
        });
    }

    /* renamed from: com.inuker.bluetooth.library.BluetoothClientImpl$9 */
    class AnonymousClass9 extends BluetoothResponse {
        final /* synthetic */ UUID val$character;
        final /* synthetic */ String val$mac;
        final /* synthetic */ BleUnnotifyResponse val$response;
        final /* synthetic */ UUID val$service;

        AnonymousClass9(String str2, UUID uuid3, UUID uuid22, BleUnnotifyResponse bleUnnotifyResponse2) {
            r2 = str2;
            r3 = uuid3;
            r4 = uuid22;
            r5 = bleUnnotifyResponse2;
        }

        @Override // com.inuker.bluetooth.library.connect.response.BluetoothResponse
        protected void onAsyncResponse(int i, Bundle bundle2) {
            BluetoothClientImpl.this.checkRuntime(true);
            BluetoothClientImpl.this.removeNotifyListener(r2, r3, r4);
            BleUnnotifyResponse bleUnnotifyResponse2 = r5;
            if (bleUnnotifyResponse2 != null) {
                bleUnnotifyResponse2.onResponse(i);
            }
        }
    }

    @Override // com.inuker.bluetooth.library.IBluetoothClient
    public void indicate(String str, UUID uuid, UUID uuid2, BleNotifyResponse bleNotifyResponse) {
        Bundle bundle = new Bundle();
        bundle.putString(Constants.EXTRA_MAC, str);
        bundle.putSerializable(Constants.EXTRA_SERVICE_UUID, uuid);
        bundle.putSerializable(Constants.EXTRA_CHARACTER_UUID, uuid2);
        safeCallBluetoothApi(10, bundle, new BluetoothResponse() { // from class: com.inuker.bluetooth.library.BluetoothClientImpl.10
            final /* synthetic */ UUID val$character;
            final /* synthetic */ String val$mac;
            final /* synthetic */ BleNotifyResponse val$response;
            final /* synthetic */ UUID val$service;

            AnonymousClass10(BleNotifyResponse bleNotifyResponse2, String str2, UUID uuid3, UUID uuid22) {
                r2 = bleNotifyResponse2;
                r3 = str2;
                r4 = uuid3;
                r5 = uuid22;
            }

            @Override // com.inuker.bluetooth.library.connect.response.BluetoothResponse
            protected void onAsyncResponse(int i, Bundle bundle2) {
                BluetoothClientImpl.this.checkRuntime(true);
                BleNotifyResponse bleNotifyResponse2 = r2;
                if (bleNotifyResponse2 != null) {
                    if (i == 0) {
                        BluetoothClientImpl.this.saveNotifyListener(r3, r4, r5, bleNotifyResponse2);
                    }
                    r2.onResponse(i);
                }
            }
        });
    }

    /* renamed from: com.inuker.bluetooth.library.BluetoothClientImpl$10 */
    class AnonymousClass10 extends BluetoothResponse {
        final /* synthetic */ UUID val$character;
        final /* synthetic */ String val$mac;
        final /* synthetic */ BleNotifyResponse val$response;
        final /* synthetic */ UUID val$service;

        AnonymousClass10(BleNotifyResponse bleNotifyResponse2, String str2, UUID uuid3, UUID uuid22) {
            r2 = bleNotifyResponse2;
            r3 = str2;
            r4 = uuid3;
            r5 = uuid22;
        }

        @Override // com.inuker.bluetooth.library.connect.response.BluetoothResponse
        protected void onAsyncResponse(int i, Bundle bundle2) {
            BluetoothClientImpl.this.checkRuntime(true);
            BleNotifyResponse bleNotifyResponse2 = r2;
            if (bleNotifyResponse2 != null) {
                if (i == 0) {
                    BluetoothClientImpl.this.saveNotifyListener(r3, r4, r5, bleNotifyResponse2);
                }
                r2.onResponse(i);
            }
        }
    }

    @Override // com.inuker.bluetooth.library.IBluetoothClient
    public void unindicate(String str, UUID uuid, UUID uuid2, BleUnnotifyResponse bleUnnotifyResponse) {
        unnotify(str, uuid, uuid2, bleUnnotifyResponse);
    }

    @Override // com.inuker.bluetooth.library.IBluetoothClient
    public void readRssi(String str, BleReadRssiResponse bleReadRssiResponse) {
        Bundle bundle = new Bundle();
        bundle.putString(Constants.EXTRA_MAC, str);
        safeCallBluetoothApi(8, bundle, new BluetoothResponse() { // from class: com.inuker.bluetooth.library.BluetoothClientImpl.11
            final /* synthetic */ BleReadRssiResponse val$response;

            AnonymousClass11(BleReadRssiResponse bleReadRssiResponse2) {
                r2 = bleReadRssiResponse2;
            }

            @Override // com.inuker.bluetooth.library.connect.response.BluetoothResponse
            protected void onAsyncResponse(int i, Bundle bundle2) {
                BluetoothClientImpl.this.checkRuntime(true);
                BleReadRssiResponse bleReadRssiResponse2 = r2;
                if (bleReadRssiResponse2 != null) {
                    bleReadRssiResponse2.onResponse(i, Integer.valueOf(bundle2.getInt(Constants.EXTRA_RSSI, 0)));
                }
            }
        });
    }

    /* renamed from: com.inuker.bluetooth.library.BluetoothClientImpl$11 */
    class AnonymousClass11 extends BluetoothResponse {
        final /* synthetic */ BleReadRssiResponse val$response;

        AnonymousClass11(BleReadRssiResponse bleReadRssiResponse2) {
            r2 = bleReadRssiResponse2;
        }

        @Override // com.inuker.bluetooth.library.connect.response.BluetoothResponse
        protected void onAsyncResponse(int i, Bundle bundle2) {
            BluetoothClientImpl.this.checkRuntime(true);
            BleReadRssiResponse bleReadRssiResponse2 = r2;
            if (bleReadRssiResponse2 != null) {
                bleReadRssiResponse2.onResponse(i, Integer.valueOf(bundle2.getInt(Constants.EXTRA_RSSI, 0)));
            }
        }
    }

    @Override // com.inuker.bluetooth.library.IBluetoothClient
    public void requestMtu(String str, int i, BleMtuResponse bleMtuResponse) {
        Bundle bundle = new Bundle();
        bundle.putString(Constants.EXTRA_MAC, str);
        bundle.putInt(Constants.EXTRA_MTU, i);
        safeCallBluetoothApi(22, bundle, new BluetoothResponse() { // from class: com.inuker.bluetooth.library.BluetoothClientImpl.12
            final /* synthetic */ BleMtuResponse val$response;

            AnonymousClass12(BleMtuResponse bleMtuResponse2) {
                r2 = bleMtuResponse2;
            }

            @Override // com.inuker.bluetooth.library.connect.response.BluetoothResponse
            protected void onAsyncResponse(int i2, Bundle bundle2) {
                BluetoothClientImpl.this.checkRuntime(true);
                BleMtuResponse bleMtuResponse2 = r2;
                if (bleMtuResponse2 != null) {
                    bleMtuResponse2.onResponse(i2, Integer.valueOf(bundle2.getInt(Constants.EXTRA_MTU, 23)));
                }
            }
        });
    }

    /* renamed from: com.inuker.bluetooth.library.BluetoothClientImpl$12 */
    class AnonymousClass12 extends BluetoothResponse {
        final /* synthetic */ BleMtuResponse val$response;

        AnonymousClass12(BleMtuResponse bleMtuResponse2) {
            r2 = bleMtuResponse2;
        }

        @Override // com.inuker.bluetooth.library.connect.response.BluetoothResponse
        protected void onAsyncResponse(int i2, Bundle bundle2) {
            BluetoothClientImpl.this.checkRuntime(true);
            BleMtuResponse bleMtuResponse2 = r2;
            if (bleMtuResponse2 != null) {
                bleMtuResponse2.onResponse(i2, Integer.valueOf(bundle2.getInt(Constants.EXTRA_MTU, 23)));
            }
        }
    }

    @Override // com.inuker.bluetooth.library.IBluetoothClient
    public void search(SearchRequest searchRequest, SearchResponse searchResponse) {
        Bundle bundle = new Bundle();
        bundle.putParcelable(Constants.EXTRA_REQUEST, searchRequest);
        safeCallBluetoothApi(11, bundle, new BluetoothResponse() { // from class: com.inuker.bluetooth.library.BluetoothClientImpl.13
            final /* synthetic */ SearchResponse val$response;

            AnonymousClass13(SearchResponse searchResponse2) {
                r2 = searchResponse2;
            }

            @Override // com.inuker.bluetooth.library.connect.response.BluetoothResponse
            protected void onAsyncResponse(int i, Bundle bundle2) {
                BluetoothClientImpl.this.checkRuntime(true);
                if (r2 == null) {
                    return;
                }
                bundle2.setClassLoader(getClass().getClassLoader());
                if (i == 1) {
                    r2.onSearchStarted();
                    return;
                }
                if (i == 2) {
                    r2.onSearchStopped();
                    return;
                }
                if (i == 3) {
                    r2.onSearchCanceled();
                } else {
                    if (i == 4) {
                        r2.onDeviceFounded((SearchResult) bundle2.getParcelable(Constants.EXTRA_SEARCH_RESULT));
                        return;
                    }
                    throw new IllegalStateException("unknown code");
                }
            }
        });
    }

    /* renamed from: com.inuker.bluetooth.library.BluetoothClientImpl$13 */
    class AnonymousClass13 extends BluetoothResponse {
        final /* synthetic */ SearchResponse val$response;

        AnonymousClass13(SearchResponse searchResponse2) {
            r2 = searchResponse2;
        }

        @Override // com.inuker.bluetooth.library.connect.response.BluetoothResponse
        protected void onAsyncResponse(int i, Bundle bundle2) {
            BluetoothClientImpl.this.checkRuntime(true);
            if (r2 == null) {
                return;
            }
            bundle2.setClassLoader(getClass().getClassLoader());
            if (i == 1) {
                r2.onSearchStarted();
                return;
            }
            if (i == 2) {
                r2.onSearchStopped();
                return;
            }
            if (i == 3) {
                r2.onSearchCanceled();
            } else {
                if (i == 4) {
                    r2.onDeviceFounded((SearchResult) bundle2.getParcelable(Constants.EXTRA_SEARCH_RESULT));
                    return;
                }
                throw new IllegalStateException("unknown code");
            }
        }
    }

    @Override // com.inuker.bluetooth.library.IBluetoothClient
    public void stopSearch() {
        safeCallBluetoothApi(12, null, null);
    }

    @Override // com.inuker.bluetooth.library.IBluetoothClient
    public void registerBluetoothStateListener(BluetoothStateListener bluetoothStateListener) {
        checkRuntime(true);
        if (bluetoothStateListener == null || this.mBluetoothStateListeners.contains(bluetoothStateListener)) {
            return;
        }
        this.mBluetoothStateListeners.add(bluetoothStateListener);
    }

    @Override // com.inuker.bluetooth.library.IBluetoothClient
    public void unregisterBluetoothStateListener(BluetoothStateListener bluetoothStateListener) {
        checkRuntime(true);
        if (bluetoothStateListener != null) {
            this.mBluetoothStateListeners.remove(bluetoothStateListener);
        }
    }

    @Override // com.inuker.bluetooth.library.IBluetoothClient
    public void registerBluetoothBondListener(BluetoothBondListener bluetoothBondListener) {
        checkRuntime(true);
        if (bluetoothBondListener == null || this.mBluetoothBondListeners.contains(bluetoothBondListener)) {
            return;
        }
        this.mBluetoothBondListeners.add(bluetoothBondListener);
    }

    @Override // com.inuker.bluetooth.library.IBluetoothClient
    public void unregisterBluetoothBondListener(BluetoothBondListener bluetoothBondListener) {
        checkRuntime(true);
        if (bluetoothBondListener != null) {
            this.mBluetoothBondListeners.remove(bluetoothBondListener);
        }
    }

    @Override // com.inuker.bluetooth.library.IBluetoothClient
    public void clearRequest(String str, int i) {
        Bundle bundle = new Bundle();
        bundle.putString(Constants.EXTRA_MAC, str);
        bundle.putInt(Constants.EXTRA_TYPE, i);
        safeCallBluetoothApi(20, bundle, null);
    }

    @Override // com.inuker.bluetooth.library.IBluetoothClient
    public void refreshCache(String str) {
        checkRuntime(true);
        Bundle bundle = new Bundle();
        bundle.putString(Constants.EXTRA_MAC, str);
        safeCallBluetoothApi(21, bundle, null);
    }

    private void safeCallBluetoothApi(int i, Bundle bundle, BluetoothResponse bluetoothResponse) {
        checkRuntime(true);
        try {
            IBluetoothService bluetoothService = getBluetoothService();
            if (bluetoothService != null) {
                if (bundle == null) {
                    bundle = new Bundle();
                }
                bluetoothService.callBluetoothApi(i, bundle, bluetoothResponse);
                return;
            }
            bluetoothResponse.onResponse(-6, null);
        } catch (Throwable th) {
            BluetoothLog.e(th);
        }
    }

    @Override // com.inuker.bluetooth.library.utils.proxy.ProxyInterceptor
    public boolean onIntercept(Object obj, Method method, Object[] objArr) {
        this.mWorkerHandler.obtainMessage(1, new ProxyBulk(obj, method, objArr)).sendToTarget();
        return true;
    }

    public void notifyBluetoothManagerReady() {
        CountDownLatch countDownLatch = this.mCountDownLatch;
        if (countDownLatch != null) {
            countDownLatch.countDown();
            this.mCountDownLatch = null;
        }
    }

    private void waitBluetoothManagerReady() {
        try {
            this.mCountDownLatch.await();
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    @Override // android.os.Handler.Callback
    public boolean handleMessage(Message message) {
        int i = message.what;
        if (i == 1) {
            ProxyBulk.safeInvoke(message.obj);
        } else if (i == 2) {
            registerBluetoothReceiver();
        }
        return true;
    }

    /* renamed from: com.inuker.bluetooth.library.BluetoothClientImpl$14 */
    class AnonymousClass14 extends BluetoothStateChangeListener {
        AnonymousClass14() {
        }

        @Override // com.inuker.bluetooth.library.receiver.listener.BluetoothStateChangeListener
        protected void onBluetoothStateChanged(int i, int i2) {
            BluetoothClientImpl.this.checkRuntime(true);
            BluetoothClientImpl.this.dispatchBluetoothStateChanged(i2);
        }
    }

    private void registerBluetoothReceiver() {
        checkRuntime(true);
        BluetoothReceiver.getInstance().register(new BluetoothStateChangeListener() { // from class: com.inuker.bluetooth.library.BluetoothClientImpl.14
            AnonymousClass14() {
            }

            @Override // com.inuker.bluetooth.library.receiver.listener.BluetoothStateChangeListener
            protected void onBluetoothStateChanged(int i, int i2) {
                BluetoothClientImpl.this.checkRuntime(true);
                BluetoothClientImpl.this.dispatchBluetoothStateChanged(i2);
            }
        });
        BluetoothReceiver.getInstance().register(new BluetoothBondStateChangeListener() { // from class: com.inuker.bluetooth.library.BluetoothClientImpl.15
            AnonymousClass15() {
            }

            @Override // com.inuker.bluetooth.library.receiver.listener.BluetoothBondStateChangeListener
            protected void onBondStateChanged(String str, int i) {
                BluetoothClientImpl.this.checkRuntime(true);
                BluetoothClientImpl.this.dispatchBondStateChanged(str, i);
            }
        });
        BluetoothReceiver.getInstance().register(new BleConnectStatusChangeListener() { // from class: com.inuker.bluetooth.library.BluetoothClientImpl.16
            AnonymousClass16() {
            }

            @Override // com.inuker.bluetooth.library.receiver.listener.BleConnectStatusChangeListener
            protected void onConnectStatusChanged(String str, int i) {
                BluetoothClientImpl.this.checkRuntime(true);
                if (i == 32) {
                    BluetoothClientImpl.this.clearNotifyListener(str);
                }
                BluetoothClientImpl.this.dispatchConnectionStatus(str, i);
            }
        });
        BluetoothReceiver.getInstance().register(new BleCharacterChangeListener() { // from class: com.inuker.bluetooth.library.BluetoothClientImpl.17
            AnonymousClass17() {
            }

            @Override // com.inuker.bluetooth.library.receiver.listener.BleCharacterChangeListener
            public void onCharacterChanged(String str, UUID uuid, UUID uuid2, byte[] bArr) {
                BluetoothClientImpl.this.checkRuntime(true);
                BluetoothClientImpl.this.dispatchCharacterNotify(str, uuid, uuid2, bArr);
            }
        });
    }

    /* renamed from: com.inuker.bluetooth.library.BluetoothClientImpl$15 */
    class AnonymousClass15 extends BluetoothBondStateChangeListener {
        AnonymousClass15() {
        }

        @Override // com.inuker.bluetooth.library.receiver.listener.BluetoothBondStateChangeListener
        protected void onBondStateChanged(String str, int i) {
            BluetoothClientImpl.this.checkRuntime(true);
            BluetoothClientImpl.this.dispatchBondStateChanged(str, i);
        }
    }

    /* renamed from: com.inuker.bluetooth.library.BluetoothClientImpl$16 */
    class AnonymousClass16 extends BleConnectStatusChangeListener {
        AnonymousClass16() {
        }

        @Override // com.inuker.bluetooth.library.receiver.listener.BleConnectStatusChangeListener
        protected void onConnectStatusChanged(String str, int i) {
            BluetoothClientImpl.this.checkRuntime(true);
            if (i == 32) {
                BluetoothClientImpl.this.clearNotifyListener(str);
            }
            BluetoothClientImpl.this.dispatchConnectionStatus(str, i);
        }
    }

    /* renamed from: com.inuker.bluetooth.library.BluetoothClientImpl$17 */
    class AnonymousClass17 extends BleCharacterChangeListener {
        AnonymousClass17() {
        }

        @Override // com.inuker.bluetooth.library.receiver.listener.BleCharacterChangeListener
        public void onCharacterChanged(String str, UUID uuid, UUID uuid2, byte[] bArr) {
            BluetoothClientImpl.this.checkRuntime(true);
            BluetoothClientImpl.this.dispatchCharacterNotify(str, uuid, uuid2, bArr);
        }
    }

    public void dispatchCharacterNotify(String str, UUID uuid, UUID uuid2, byte[] bArr) {
        List<BleNotifyResponse> list;
        checkRuntime(true);
        HashMap<String, List<BleNotifyResponse>> hashMap = this.mNotifyResponses.get(str);
        if (hashMap == null || (list = hashMap.get(generateCharacterKey(uuid, uuid2))) == null) {
            return;
        }
        Iterator<BleNotifyResponse> it2 = list.iterator();
        while (it2.hasNext()) {
            it2.next().onNotify(uuid, uuid2, bArr);
        }
    }

    public void dispatchConnectionStatus(String str, int i) {
        checkRuntime(true);
        List<BleConnectStatusListener> list = this.mConnectStatusListeners.get(str);
        if (ListUtils.isEmpty(list)) {
            return;
        }
        Iterator<BleConnectStatusListener> it2 = list.iterator();
        while (it2.hasNext()) {
            it2.next().invokeSync(str, Integer.valueOf(i));
        }
    }

    public void dispatchBluetoothStateChanged(int i) {
        checkRuntime(true);
        if (i == 10 || i == 12) {
            for (BluetoothStateListener bluetoothStateListener : this.mBluetoothStateListeners) {
                Object[] objArr = new Object[1];
                objArr[0] = Boolean.valueOf(i == 12);
                bluetoothStateListener.invokeSync(objArr);
            }
        }
    }

    public void dispatchBondStateChanged(String str, int i) {
        checkRuntime(true);
        Iterator<BluetoothBondListener> it2 = this.mBluetoothBondListeners.iterator();
        while (it2.hasNext()) {
            it2.next().invokeSync(str, Integer.valueOf(i));
        }
    }

    public void checkRuntime(boolean z) {
        if (Looper.myLooper() != (z ? this.mWorkerHandler.getLooper() : Looper.getMainLooper())) {
            throw new RuntimeException();
        }
    }
}
