package no.nordicsemi.android.support.v18.scanner;

import android.os.Build;
import android.os.Handler;
import android.os.Looper;
import android.os.SystemClock;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import no.nordicsemi.android.support.v18.scanner.ScanSettings;

/* loaded from: classes2.dex */
public abstract class BluetoothLeScannerCompat {
    private static BluetoothLeScannerCompat mInstance;
    private final Handler mHandler = new Handler(Looper.getMainLooper());

    public abstract void flushPendingScanResults(ScanCallback scanCallback);

    abstract void startScanInternal(List<ScanFilter> list, ScanSettings scanSettings, ScanCallback scanCallback);

    public abstract void stopScan(ScanCallback scanCallback);

    public static BluetoothLeScannerCompat getScanner() {
        BluetoothLeScannerCompat bluetoothLeScannerCompat = mInstance;
        if (bluetoothLeScannerCompat != null) {
            return bluetoothLeScannerCompat;
        }
        if (Build.VERSION.SDK_INT >= 23) {
            BluetoothLeScannerImplMarshmallow bluetoothLeScannerImplMarshmallow = new BluetoothLeScannerImplMarshmallow();
            mInstance = bluetoothLeScannerImplMarshmallow;
            return bluetoothLeScannerImplMarshmallow;
        }
        if (Build.VERSION.SDK_INT >= 21) {
            BluetoothLeScannerImplLollipop bluetoothLeScannerImplLollipop = new BluetoothLeScannerImplLollipop();
            mInstance = bluetoothLeScannerImplLollipop;
            return bluetoothLeScannerImplLollipop;
        }
        BluetoothLeScannerImplJB bluetoothLeScannerImplJB = new BluetoothLeScannerImplJB();
        mInstance = bluetoothLeScannerImplJB;
        return bluetoothLeScannerImplJB;
    }

    BluetoothLeScannerCompat() {
    }

    public void startScan(ScanCallback scanCallback) {
        if (scanCallback == null) {
            throw new IllegalArgumentException("callback is null");
        }
        startScanInternal(null, new ScanSettings.Builder().build(), scanCallback);
    }

    public void startScan(List<ScanFilter> list, ScanSettings scanSettings, ScanCallback scanCallback) {
        if (scanSettings == null || scanCallback == null) {
            throw new IllegalArgumentException("settings or callback is null");
        }
        startScanInternal(list, scanSettings, scanCallback);
    }

    class ScanCallbackWrapper {
        private final List<String> mDevicesInBatch;
        private final Map<String, ScanResult> mDevicesInRange;
        private final List<ScanFilter> mFilters;
        private final Runnable mFlushPendingScanResultsTask;
        private MatchLostNotifierTask mMatchLostNotifierTask;
        private final ScanCallback mScanCallback;
        private final List<ScanResult> mScanResults;
        private final ScanSettings mScanSettings;

        /* renamed from: no.nordicsemi.android.support.v18.scanner.BluetoothLeScannerCompat$ScanCallbackWrapper$1 */
        class AnonymousClass1 implements Runnable {
            AnonymousClass1() {
            }

            @Override // java.lang.Runnable
            public void run() {
                ScanCallbackWrapper.this.flushPendingScanResults();
                BluetoothLeScannerCompat.this.mHandler.postDelayed(this, ScanCallbackWrapper.this.mScanSettings.getReportDelayMillis());
            }
        }

        ScanCallbackWrapper(List<ScanFilter> list, ScanSettings scanSettings, ScanCallback scanCallback) {
            AnonymousClass1 anonymousClass1 = new Runnable() { // from class: no.nordicsemi.android.support.v18.scanner.BluetoothLeScannerCompat.ScanCallbackWrapper.1
                AnonymousClass1() {
                }

                @Override // java.lang.Runnable
                public void run() {
                    ScanCallbackWrapper.this.flushPendingScanResults();
                    BluetoothLeScannerCompat.this.mHandler.postDelayed(this, ScanCallbackWrapper.this.mScanSettings.getReportDelayMillis());
                }
            };
            this.mFlushPendingScanResultsTask = anonymousClass1;
            this.mFilters = list;
            this.mScanSettings = scanSettings;
            this.mScanCallback = scanCallback;
            if (scanSettings.getCallbackType() != 1 && !scanSettings.getUseHardwareCallbackTypesIfSupported()) {
                this.mDevicesInRange = new HashMap();
            } else {
                this.mDevicesInRange = null;
            }
            long reportDelayMillis = scanSettings.getReportDelayMillis();
            if (reportDelayMillis > 0) {
                this.mScanResults = new ArrayList();
                this.mDevicesInBatch = new ArrayList();
                BluetoothLeScannerCompat.this.mHandler.postDelayed(anonymousClass1, reportDelayMillis);
            } else {
                this.mScanResults = null;
                this.mDevicesInBatch = null;
            }
        }

        void close() {
            if (this.mScanResults != null) {
                BluetoothLeScannerCompat.this.mHandler.removeCallbacks(this.mFlushPendingScanResultsTask);
            }
            Map<String, ScanResult> map = this.mDevicesInRange;
            if (map != null) {
                map.clear();
            }
            if (this.mMatchLostNotifierTask != null) {
                BluetoothLeScannerCompat.this.mHandler.removeCallbacks(this.mMatchLostNotifierTask);
                this.mMatchLostNotifierTask = null;
            }
        }

        ScanSettings getScanSettings() {
            return this.mScanSettings;
        }

        List<ScanFilter> getScanFilters() {
            return this.mFilters;
        }

        ScanCallback getScanCallback() {
            return this.mScanCallback;
        }

        void flushPendingScanResults() {
            List<ScanResult> list = this.mScanResults;
            if (list != null) {
                synchronized (list) {
                    this.mScanCallback.onBatchScanResults(this.mScanResults);
                    this.mScanResults.clear();
                    this.mDevicesInBatch.clear();
                }
            }
        }

        private class MatchLostNotifierTask implements Runnable {
            private final List<ScanResult> mMatchLostScanResults;

            private MatchLostNotifierTask() {
                this.mMatchLostScanResults = new ArrayList();
            }

            /* synthetic */ MatchLostNotifierTask(ScanCallbackWrapper scanCallbackWrapper, AnonymousClass1 anonymousClass1) {
                this();
            }

            @Override // java.lang.Runnable
            public void run() {
                long elapsedRealtimeNanos = SystemClock.elapsedRealtimeNanos();
                for (ScanResult scanResult : ScanCallbackWrapper.this.mDevicesInRange.values()) {
                    if (scanResult.getTimestampNanos() < elapsedRealtimeNanos - ScanCallbackWrapper.this.mScanSettings.getMatchLostDeviceTimeout()) {
                        this.mMatchLostScanResults.add(scanResult);
                    }
                }
                if (!this.mMatchLostScanResults.isEmpty()) {
                    for (ScanResult scanResult2 : this.mMatchLostScanResults) {
                        ScanCallbackWrapper.this.mDevicesInRange.remove(scanResult2.getDevice().getAddress());
                        ScanCallbackWrapper.this.onFoundOrLost(false, scanResult2);
                    }
                    this.mMatchLostScanResults.clear();
                }
                BluetoothLeScannerCompat.this.mHandler.postDelayed(ScanCallbackWrapper.this.mMatchLostNotifierTask, ScanCallbackWrapper.this.mScanSettings.getMatchLostTaskInterval());
            }
        }

        void handleScanResult(ScanResult scanResult) {
            List<ScanFilter> list = this.mFilters;
            if (list == null || list.isEmpty() || matches(scanResult)) {
                String address = scanResult.getDevice().getAddress();
                Map<String, ScanResult> map = this.mDevicesInRange;
                if (map != null) {
                    if (map.put(address, scanResult) == null && (this.mScanSettings.getCallbackType() & 2) > 0) {
                        onFoundOrLost(true, scanResult);
                    }
                    if ((this.mScanSettings.getCallbackType() & 4) <= 0 || this.mMatchLostNotifierTask != null) {
                        return;
                    }
                    this.mMatchLostNotifierTask = new MatchLostNotifierTask();
                    BluetoothLeScannerCompat.this.mHandler.postDelayed(this.mMatchLostNotifierTask, this.mScanSettings.getMatchLostTaskInterval());
                    return;
                }
                if (this.mScanSettings.getReportDelayMillis() > 0) {
                    synchronized (this.mScanResults) {
                        if (!this.mDevicesInBatch.contains(address)) {
                            this.mScanResults.add(scanResult);
                            this.mDevicesInBatch.add(address);
                        }
                    }
                    return;
                }
                onScanResult(scanResult);
            }
        }

        void handleScanResults(List<ScanResult> list, boolean z) {
            if (this.mFilters != null && (!z || !this.mScanSettings.getUseHardwareFilteringIfSupported())) {
                ArrayList arrayList = new ArrayList();
                for (ScanResult scanResult : list) {
                    if (matches(scanResult)) {
                        arrayList.add(scanResult);
                    }
                }
                list = arrayList;
            }
            onBatchScanResults(list);
        }

        private boolean matches(ScanResult scanResult) {
            Iterator<ScanFilter> it2 = this.mFilters.iterator();
            while (it2.hasNext()) {
                if (it2.next().matches(scanResult)) {
                    return true;
                }
            }
            return false;
        }

        /* renamed from: no.nordicsemi.android.support.v18.scanner.BluetoothLeScannerCompat$ScanCallbackWrapper$2 */
        class AnonymousClass2 implements Runnable {
            final /* synthetic */ ScanResult val$scanResult;

            AnonymousClass2(ScanResult scanResult) {
                r2 = scanResult;
            }

            @Override // java.lang.Runnable
            public void run() {
                ScanCallbackWrapper.this.mScanCallback.onScanResult(1, r2);
            }
        }

        private void onScanResult(ScanResult scanResult) {
            BluetoothLeScannerCompat.this.mHandler.post(new Runnable() { // from class: no.nordicsemi.android.support.v18.scanner.BluetoothLeScannerCompat.ScanCallbackWrapper.2
                final /* synthetic */ ScanResult val$scanResult;

                AnonymousClass2(ScanResult scanResult2) {
                    r2 = scanResult2;
                }

                @Override // java.lang.Runnable
                public void run() {
                    ScanCallbackWrapper.this.mScanCallback.onScanResult(1, r2);
                }
            });
        }

        /* renamed from: no.nordicsemi.android.support.v18.scanner.BluetoothLeScannerCompat$ScanCallbackWrapper$3 */
        class AnonymousClass3 implements Runnable {
            final /* synthetic */ List val$results;

            AnonymousClass3(List list) {
                r2 = list;
            }

            @Override // java.lang.Runnable
            public void run() {
                ScanCallbackWrapper.this.mScanCallback.onBatchScanResults(r2);
            }
        }

        private void onBatchScanResults(List<ScanResult> list) {
            BluetoothLeScannerCompat.this.mHandler.post(new Runnable() { // from class: no.nordicsemi.android.support.v18.scanner.BluetoothLeScannerCompat.ScanCallbackWrapper.3
                final /* synthetic */ List val$results;

                AnonymousClass3(List list2) {
                    r2 = list2;
                }

                @Override // java.lang.Runnable
                public void run() {
                    ScanCallbackWrapper.this.mScanCallback.onBatchScanResults(r2);
                }
            });
        }

        /* renamed from: no.nordicsemi.android.support.v18.scanner.BluetoothLeScannerCompat$ScanCallbackWrapper$4 */
        class AnonymousClass4 implements Runnable {
            final /* synthetic */ boolean val$onFound;
            final /* synthetic */ ScanResult val$scanResult;

            AnonymousClass4(boolean z, ScanResult scanResult) {
                r2 = z;
                r3 = scanResult;
            }

            @Override // java.lang.Runnable
            public void run() {
                if (r2) {
                    ScanCallbackWrapper.this.mScanCallback.onScanResult(2, r3);
                } else {
                    ScanCallbackWrapper.this.mScanCallback.onScanResult(4, r3);
                }
            }
        }

        public void onFoundOrLost(boolean z, ScanResult scanResult) {
            BluetoothLeScannerCompat.this.mHandler.post(new Runnable() { // from class: no.nordicsemi.android.support.v18.scanner.BluetoothLeScannerCompat.ScanCallbackWrapper.4
                final /* synthetic */ boolean val$onFound;
                final /* synthetic */ ScanResult val$scanResult;

                AnonymousClass4(boolean z2, ScanResult scanResult2) {
                    r2 = z2;
                    r3 = scanResult2;
                }

                @Override // java.lang.Runnable
                public void run() {
                    if (r2) {
                        ScanCallbackWrapper.this.mScanCallback.onScanResult(2, r3);
                    } else {
                        ScanCallbackWrapper.this.mScanCallback.onScanResult(4, r3);
                    }
                }
            });
        }

        void onScanManagerErrorCallback(int i) {
            BluetoothLeScannerCompat.this.postCallbackError(this.mScanCallback, i);
        }
    }

    /* renamed from: no.nordicsemi.android.support.v18.scanner.BluetoothLeScannerCompat$1 */
    class AnonymousClass1 implements Runnable {
        final /* synthetic */ ScanCallback val$callback;
        final /* synthetic */ int val$errorCode;

        AnonymousClass1(ScanCallback scanCallback, int i) {
            r2 = scanCallback;
            r3 = i;
        }

        @Override // java.lang.Runnable
        public void run() {
            r2.onScanFailed(r3);
        }
    }

    public void postCallbackError(ScanCallback scanCallback, int i) {
        this.mHandler.post(new Runnable() { // from class: no.nordicsemi.android.support.v18.scanner.BluetoothLeScannerCompat.1
            final /* synthetic */ ScanCallback val$callback;
            final /* synthetic */ int val$errorCode;

            AnonymousClass1(ScanCallback scanCallback2, int i2) {
                r2 = scanCallback2;
                r3 = i2;
            }

            @Override // java.lang.Runnable
            public void run() {
                r2.onScanFailed(r3);
            }
        });
    }
}
